#

##

##

    	besties (and bosses)

    		@ treaties
    			@ customs
    			@ terrifs

    		@ parties
    		@ groups
    		@ friends

    		# stack
    		# external APIs
    		# partners
    		#

    	summary
    		USDA foods and NIH supps are parsed
    		into shows.treasure.pattern_1

    	possibilities
    		https://www.foodchainid.com/

    		Poison Control:
    			https://www.poison.org/

    		https://www.nal.usda.gov/economics-business-and-trade/agricultural-subsidies

    		https://farm.ewg.org/

    		https://usafacts.org/topics/agriculture/

    			2022:
    				$1.56 E +10